@@ -14,7 +14,7 @@ import repr
 import struct
 import sys
 
-# sys.path.insert(0, '..')
+sys.path.insert(0, '..')
 from pyunv.universe import Universe, Parameters, Class, Object, Condition, Table, VirtualTable
 
 # import pyunv
@@ -87,13 +87,13 @@ class Reader(object):
         
         params = Parameters()
         struct.unpack('<2I', self.file.read(8))
-        params.universe_filename, = self.read_shortstring()
-        params.universe_name, = self.read_shortstring()
+        params.universe_filename = self.read_shortstring()
+        params.universe_name = self.read_shortstring()
         params.revision, = struct.unpack('<I', self.file.read(4))
         struct.unpack('<H', self.file.read(2))
-        params.description, = self.read_shortstring()
-        params.created_by, = self.read_shortstring()
-        params.modified_by, = self.read_shortstring()
+        params.description = self.read_shortstring()
+        params.created_by = self.read_shortstring()
+        params.modified_by = self.read_shortstring()
         created, modified, = struct.unpack('<2I', self.file.read(8))
         params.created_date = self.date_from_dateindex(created)
         params.modified_date = self.date_from_dateindex(modified)
@@ -101,17 +101,17 @@ class Reader(object):
         params.query_time_limit = seconds / 60
         params.row_limit, = struct.unpack('<I', self.file.read(4))
         self.read_shortstring()
-        params.object_strategy, = self.read_shortstring()
+        params.object_strategy = self.read_shortstring()
         struct.unpack('<x', self.file.read(1))
         seconds, = struct.unpack('<I', self.file.read(4))
         params.cost_estimate_warning_limit = seconds / 60
         params.long_text_limit, = struct.unpack('<I', self.file.read(4))
         struct.unpack('<4x', self.file.read(4))
-        params.comments, = self.read_shortstring()
+        params.comments = self.read_shortstring()
         struct.unpack('<3I', self.file.read(12))
-        params.domain, = self.read_shortstring()
-        params.dbms_engine, = self.read_shortstring()
-        params.network_layer, = self.read_shortstring()
+        params.domain = self.read_shortstring()
+        params.dbms_engine = self.read_shortstring()
+        params.network_layer = self.read_shortstring()
         
         return params
 
@@ -130,8 +130,8 @@ class Reader(object):
         """
         self.file.seek(self.content_offsets['Tables;'])
         struct.unpack('<2B', self.file.read(2))
-        schema_name, = self.read_shortstring()
-        user_name, = self.read_shortstring()
+        schema_name = self.read_shortstring()
+        user_name = self.read_shortstring()
         max_table_id, = struct.unpack('<I', self.file.read(4))
         table_count, = struct.unpack('<I', self.file.read(4))
         return [self.read_table() for x in range(table_count)]
@@ -171,7 +171,7 @@ class Reader(object):
         id_, = struct.unpack('<I', self.file.read(4))
         struct.unpack('<7x', self.file.read(7))
         struct.unpack('<3I', self.file.read(12))
-        name, = self.read_shortstring()
+        name = self.read_shortstring()
         struct.unpack('<15x', self.file.read(15))
         return Table(id_, name)
 
@@ -183,7 +183,7 @@ class Reader(object):
         
         """
         table_id, = struct.unpack('<I', self.file.read(4))
-        select, = self.read_shortstring()
+        select = self.read_shortstring()
         return VirtualTable(table_id, select)
 
     def read_class(self):
@@ -203,9 +203,9 @@ class Reader(object):
 
         """
         id_, = struct.unpack('<I', self.file.read(4))
-        name, = self.read_shortstring()
+        name = self.read_shortstring()
         parent, = struct.unpack('<I', self.file.read(4))
-        description, = self.read_shortstring()
+        description = self.read_shortstring()
         c = Class(self.universe, id_, parent, name, description)
         self.file.seek(7, os.SEEK_CUR)
         object_count, = struct.unpack('<I', self.file.read(4))
@@ -236,19 +236,19 @@ class Reader(object):
 
        """
         id_, = struct.unpack('<I', self.file.read(4))
-        name, = self.read_shortstring()
+        name = self.read_shortstring()
         parent, = struct.unpack('<I', self.file.read(4))
-        description, = self.read_shortstring()
+        description = self.read_shortstring()
         o = Object(self.universe, id_, parent, name, description)
         select_tablecount, = struct.unpack('<H', self.file.read(2))
         struct.unpack('<%dI' % select_tablecount, self.file.read(4 * select_tablecount))
         where_tablecount, = struct.unpack('<H', self.file.read(2))
         struct.unpack('<%dI' % where_tablecount, self.file.read(4 * where_tablecount))
-        o.select, = self.read_shortstring()
-        o.where, = self.read_shortstring()
-        o.format, = self.read_shortstring()
-        unknown2, = self.read_shortstring()
-        o.lov_name, = self.read_shortstring()
+        o.select = self.read_shortstring()
+        o.where = self.read_shortstring()
+        o.format = self.read_shortstring()
+        unknown2 = self.read_shortstring()
+        o.lov_name = self.read_shortstring()
         self.file.seek(58, os.SEEK_CUR)
         return o
 
@@ -267,24 +267,25 @@ class Reader(object):
 
         """
         id_, = struct.unpack('<I', self.file.read(4))
-        name, = self.read_shortstring()
+        name = self.read_shortstring()
         parent, = struct.unpack('<I', self.file.read(4))
-        description, = self.read_shortstring()
+        description = self.read_shortstring()
         c = Condition(self.universe, id_, name, parent, description)
         where_tablecount, = struct.unpack('<H', self.file.read(2))
         struct.unpack('<%dI' % where_tablecount, self.file.read(4 * where_tablecount))
         unknown_tablecount, = struct.unpack('<H', self.file.read(2))
         struct.unpack('<%dI' % unknown_tablecount, self.file.read(4 * unknown_tablecount))
-        c.where, = self.read_shortstring()
+        c.where = self.read_shortstring()
         return c
 
     def read_shortstring(self):
         """read a short variable-length string from the universe file"""
         length, = struct.unpack('<H', self.file.read(2))
         if length:
-            return struct.unpack('<%ds' % length, self.file.read(length))
+            s, = struct.unpack('<%ds' % length, self.file.read(length))
+            return unicode(s.translate(None, '\x0d\x0a'), errors='ignore')
         else:
-            return (None,)
+            return None
 
     def date_from_dateindex(self, dateindex):
         """return the date corresponding to the BusinessObjects universe date index"""
@@ -293,18 +294,26 @@ class Reader(object):
 
 import csv
 import unittest
+from manifest import Manifest
 
 class ReaderTests(unittest.TestCase):
     def setUp(self):
-        self.filename = 'Universes/Universe_A8.unv'
+        self.filename = 'tests/Universe_A8.unv'
             
     def testreader(self):
         universe = Reader(open(self.filename, 'rb')).universe
 
-    def testexport(self):
-        universe = Reader(open(self.filename, 'rb')).universe
-        CsvWriter(universe, open(os.path.splitext(self.filename)[0]+'.csv', 'wb'))
+    # def testexport(self):
+    #     universe = Reader(open(self.filename, 'rb')).universe
+    #     CsvWriter(universe, open(os.path.splitext(self.filename)[0]+'.csv', 'wb'))
 
+    def testmanifest(self):
+        universe = Reader(open(self.filename, 'rb')).universe
+        f = open(self.filename+'.manifest.txt', 'w')
+        manifest = Manifest()
+        manifest.save(f, universe)
+        f.close()
+        
 
 if __name__ == '__main__':
     unittest.main()
